function [HEV,CV]=getHEVCV(dd)

global PTCM VEHLIFE sLIFE yLIFE
global c v k dmax rN rR rN D ctax
FS = @(y)1-exp(-k*y);
FE = @(y)1/k-exp(-k*y)*(y+1/k);
prob = exppdf(dd,1/k);
HEV.mpg=60.1;
CV.mpg = 29.5;
% CV: 126kW engine & 29.5 mpg (modified from Honda Accord)
% HEV NiMH battery unit cost = $600/kWh 
HEV.vehghgs  = v.BASE+1.31*v.NiMH;
CV.vehghgs  = v.BASE;
%
if PTCM=='E', % the base powertrain model in the paper (EPRI)
    HEV.vehcost = c.BASE+(17.8* 57+650)+(26.6*52+520)+1.31*c.NiMH;
    CV.vehcost  = c.BASE+(17.8*126+650); 
elseif PTCM=='L', % the LR model in the 2009 ANL report
    HEV.vehcost = c.BASE+(315+290*4+3* 57)+(25*52)+1.31*c.NiMH;
    CV.vehcost  = c.BASE+(315+290*4+3*126);
elseif PTCM=='P', % the PG model in the 2009 ANL report
    HEV.vehcost = c.BASE+(300+275*4+3* 57)+(19*52)+1.31*c.NiMH;
    CV.vehcost  = c.BASE+(300+275*4+3*126);
else
    disp('PTCM flag error.');
end

if VEHLIFE=='M', % constant life mileage (150,000 miles)	
	T = (sLIFE./dd)/D;
elseif VEHLIFE=='Y',
    T = yLIFE;
end	
    
% CRF: capital recovery factor
CRF_rNT = rN./(1-(1+rN).^(-T));
CRF_rRT = rR./(1-(1+rR).^(-T));
% coefficient for HEV using Li-ion battery

% discounted op-cost over vehicle life
HEV.EACday=(dd.*(c.gas+v.gas*ctax)/HEV.mpg).*CRF_rNT./CRF_rRT ...
         +(HEV.vehcost+ctax*HEV.vehghgs)./D.*CRF_rNT;
 CV.EACday=(dd.*(c.gas+v.gas*ctax)/ CV.mpg).*CRF_rNT./CRF_rRT ...
         +( CV.vehcost+ctax*HEV.vehghgs)./D.*CRF_rNT;

% GHG emissions of NiMH battery is  = $230/kWh (Costa's paper)
HEV.fuelmile = 1/HEV.mpg;
HEV.fuelday  = dd.*HEV.fuelmile;
HEV.fuelpdf  = prob.*HEV.fuelday;
%
HEV.ghgsmile = HEV.vehghgs/sLIFE + v.gas/HEV.mpg;
HEV.ghgsday  = dd.*HEV.ghgsmile;
HEV.ghgspdf  = prob.*HEV.ghgsday;
%
HEV.costday  = HEV.EACday;
HEV.costmile = HEV.EACday./dd; HEV.costmile(1) = 0;
HEV.costpdf  = prob.*HEV.costday;
%
CV.fuelmile = 1/CV.mpg;
CV.fuelday  = dd.*CV.fuelmile;
CV.fuelpdf  = prob.*CV.fuelday;
%
CV.ghgsmile = CV.vehghgs/sLIFE + v.gas/CV.mpg; 
CV.ghgsday  = dd.*CV.ghgsmile;
CV.ghgspdf  = prob.*CV.ghgsday;
%
CV.costday  = CV.EACday;
CV.costmile = CV.EACday./dd; CV.costmile(1) = 0;
CV.costpdf  = prob.*CV.costday;
