function [fval,BVP]=getcostPHEV(x,ds)
% Code to calcualte equivalent annualized cost (EAC) of PHEV

% modified version to be able to take ds as vector
% in order to improve computational effeiciency in optimization
global PTCM BATDR BATAS BATEOL VEHLIFE BATCRD yLIFE sLIFE
global D rR rN c kappa alpha effBAT effCHG v ctax

% Coefficient in Rosenkranz DOD-based degradation model
b1=1449.26; b2=1.4611;
%
[eff,t60,socUS06,mu]=metafunc(x);
sAER=kappa*(1000*x(3))*x(4)*eff.CD;
% cost
cBASE = c.BASE;
if PTCM=='E', % the base powertrain model in the paper (EPRI)
    cENG = 17.8*(57*x(1))+650;
    cMTR = 26.6*(52*x(2))+520;
elseif PTCM=='L', % the LR model in the 2009 ANL report
    cENG = 315+290*4+3*(57*x(1));
    cMTR = 25*(52*x(2));
elseif PTCM=='P', % the PG model in the 2009 ANL report
    cENG = 300+275*4+3*(57*x(1));
    cMTR = 19*(52*x(2));
end

cBAT = c.LiIon*kappa*(x(3)*1000); % unit of c.LiIon = $/kWh
cVEH = cBASE+cENG+cMTR;

if BATCRD=='Y',
   batcap=kappa*(x(3)*1000); % battery capacity in kWh
   taxcredit=(batcap>=5)*(min(7500,2500+417+417*(batcap-5)));
   cVEH=cVEH-taxcredit;
end
%
sE=(ds<=sAER).*ds+(ds>sAER).*sAER; % distance travelled on eletricity
sG= (ds>sAER).*(ds-sAER); % distance travelled on gasoline
%
if BATEOL=='S', % rEOL = 1 - swing
    rEOL=(1-x(4));
elseif BATEOL=='2', % rEOL = fixed 20% capacity fade
    rEOL=0.20;
end

if BATDR=='P',  % Peterson's A123 battery degradation model
    % w.CD and w.CS (unit: kWh) energy processed for one UDDS cycle
    wDRV=(sE.*mu.CD+sG.*mu.CS)/(x(3)*1000); % kWh processed on driving  per cell per day
    wCHG=(sE./eff.CD/effBAT)/(x(3)*1000);        % kWh processed on charging per cell per day
    % Peterson's model shows that total energy processed for one A123 cell
    % divided by 21.6 Wh for normalization per original Wh 
    thetaBAT=rEOL./((alpha.DRV.*wDRV+alpha.CHG.*wCHG)/kappa);
elseif BATDR=='R',  % Rosenkrantz's VARTA data curve
    DOD=sE./(kappa*(1000*x(3))*eff.CD);  % DOD
    thetaBAT=b1.*DOD.^(-b2);
end

% CD mode: ds<=AER 
% CS mode: ds> AER
cOP= c.elec/effCHG/eff.CD.*(ds<=sAER).*ds ...
    +(ds>sAER).*(c.elec/effCHG/eff.CD*sAER + c.gas/eff.CS*(ds-sAER));

if VEHLIFE=='M', % constant life mileage (150,000 miles)	
	thetaVEH = sLIFE./ds;
	T = thetaVEH/D;
elseif VEHLIFE=='Y',
    T=yLIFE;
	thetaVEH=T*D;
end	
B = thetaBAT/D;

% Penalty term for vehicle life greater than battery life
BVP=sum((T>B).*(T-B).^2);

% CRF: capital recovery factor
CRF_rNT = rN./(1-(1+rN).^(-T));
CRF_rRT = rR./(1-(1+rR).^(-T));
CRF_rNB = rN./(1-(1+rN).^(-B));

if ctax>0,
	[ghgsday,vOP,vVEHday]=getghgsPHEV(x,ds);
	vBAT = v.LiIon*(x(3)*1000)*kappa; 
	cBATbuy  =(cBAT+vBAT*ctax)./D.*CRF_rNT; % battery purhcase cost ($/day)
	cBATlease=(cBAT+vBAT*ctax)./D.*CRF_rNB; % battery lease cost ($/day)
else
	cBATbuy  =cBAT./D.*CRF_rNT; % battery purhcase cost ($/day)
	cBATlease=cBAT./D.*CRF_rNB; % battery lease cost ($/day)
end
	
% for buy-lease case
cBATbuylease=(T<=B).*cBATbuy + (T>B).*cBATlease;
if BATAS=='L', % lease
    cBATday=cBATlease;
elseif BATAS=='1', % Buy-lease scenario
    cBATday=cBATbuylease;
end

% equivalent annual cost (EAC) per day (unit: $/day)
if ctax>0,
	EACday = (cOP+vOP*ctax).*CRF_rNT./CRF_rRT + (cVEH./D+vVEHday*ctax).*CRF_rNT + cBATday;
else
	EACday = cOP.*CRF_rNT./CRF_rRT + (cVEH./D).*CRF_rNT + cBATday;
end

fval=EACday;
